@@ -11,7 +11,6 @@ import queue
 import string
 from xtea import MODE_CBC, new
 from colr import color
-import sys
 
 JOINTIMEOUT = 3
 RECEIVEMQSITZE = 10
@@ -283,7 +282,7 @@ class DcsConnection:
             return
 
         if(msgtype == 4):
-            logging.info(str(id(self)) + " TID: " + str(tid) + "; Received Curent Data Request.")
+            logging.debug(str(id(self)) + " TID: " + str(tid) + "; Received Curent Data Request.")
             try:
                 self.senddata(tid=tid)
             except Exception as e:
@@ -524,7 +523,7 @@ class DcsConnection:
                 if(difference.total_seconds() > MAXIMUMTRANSACTIONTIME):
                     logging.warning(str(id(self)) + " TID: " + str(tid) + "; Type: " + str(msgtype) + " transaction time to hight! " + str(difference.total_seconds()))
 
-                logging.info(str(id(self)) + " TID: " + str(tid) + "; Type: " + str(msgtype) + " successfull send. Transaction-time: " + str(difference.total_seconds()))
+                logging.debug(str(id(self)) + " TID: " + str(tid) + "; Type: " + str(msgtype) + " successfull send. Transaction-time: " + str(difference.total_seconds()))
                 return True
             else:
                 return False
