@@ -16,7 +16,7 @@ from mypvdevices.ModbusRtuDevice import ModbusRtuDevice
 from mypvdevices.ModbusConnection import ModbusConnection
 
 MODBUSWARNLEVEL = 0.5
-REGISTERTIMEOUT = 5
+REGISTERTIMEOUT = 30
 BUILDNR = "4321"
 
 class DeviceDcElwa(ModbusRtuDevice):
@@ -83,6 +83,8 @@ class DeviceDcElwa(ModbusRtuDevice):
         else:
             errorcode = None
 
+        errorrate = self.getcommunicationerrorsrate()
+
         data={
             "device": self.__devicetype__,
             "fwversion": self.__firmwareversion__,
@@ -115,7 +117,7 @@ class DeviceDcElwa(ModbusRtuDevice):
             "temp2": self.getdataset("temp2"),
             "ww2target": self.getdataset("boost_temp_target"),
             "ww2offset": self.getdataset("ww2offset_calibration"),
-            "modbuserrorrate":  self.getcommunicationerrorsrate(),
+            "modbuserrorrate":  errorrate,
             "errorcode": errorcode
         }       
         return data
@@ -126,7 +128,7 @@ class DeviceDcElwa(ModbusRtuDevice):
         else:
             return None
 
-    def getlogdata(self):
+    def getlogdata(self, time = None):
         acRelayState = self.getlogvalue("ac_relay_state")
         if acRelayState != None:
             boostpower = int(round(acRelayState*750))
@@ -176,7 +178,8 @@ class DeviceDcElwa(ModbusRtuDevice):
 			"ww2offset": self.getintlogvalue("ww2offset_calibration"),
         }
 
-        logData = { 
+        logData = {
+            "time": time,
             "i_power": power,
             "i_boostpower": boostpower,
             "i_m1sum": pvprod,
@@ -187,7 +190,7 @@ class DeviceDcElwa(ModbusRtuDevice):
         }
 
         ModbusConnection.instance().resetCounters(self.__nodeId__)
-        self.__logdata__.clear()
+        # self.__logdata__.clear()  #todo sicher?
         return logData
 
     def getintlogvalue(self, datasetname):
@@ -203,13 +206,11 @@ class DeviceDcElwa(ModbusRtuDevice):
             return None
 
     def __checkRegiterTimeStamp__(self):
-        if self.__registerLastSuccessfullReadTimeStamp__ != None:
+        if self.__registerLastSuccessfullReadTimeStamp__ != None and len(self.__registers__) > 0:
             difference = time.time() - self.__registerLastSuccessfullReadTimeStamp__
             if(difference > REGISTERTIMEOUT):
-                return False
-            return True
-        else:
-            return False
+                return False    
+        return True
     
     def __supervise__(self):
 
@@ -240,15 +241,11 @@ class DeviceDcElwa(ModbusRtuDevice):
             modbusError = False
         else:
             logging.debug("[DeviceDcElwa] " + self.getidentifier() + " - Modbus module not present.")
+            ModbusConnection.instance().resetCounters(self.__nodeId__)
             modbusError = True
 
         modbusErrorRate = self.getcommunicationerrorsrate()
-        if modbusError != True and modbusErrorRate != None and modbusErrorRate > MODBUSWARNLEVEL and modbusErrorRate < 1:
-            logging.warning("[DeviceDcElwa] " + self.getidentifier() + " - Modbus error rate to hight " + str(modbusErrorRate) + ".")
-            modbusWarning = True
-        else:
-            modbusWarning = False
-
+        
         if modbusError == False:
             if modbusErrorRate == 1 :
                 logging.warning("[DeviceDcElwa] " + self.getidentifier() + " - Modbus communication to device not working.")
@@ -256,8 +253,21 @@ class DeviceDcElwa(ModbusRtuDevice):
             else:
                 modbusError = False
 
+        registerisvalid = self.__checkRegiterTimeStamp__()
+        if registerisvalid != True and modbusError == False:
+            logging.warning("[DeviceDcElwa] " + self.getidentifier() + " - Register values too old. Communication errors expected. Registers: " + str(self.__registers__) + " Timestamp: " + str(self.__registerLastSuccessfullReadTimeStamp__) + " Age: " + str(time.time() - self.__registerLastSuccessfullReadTimeStamp__))
+            registerError = True
+        else:
+            registerError = False
+
+        if registerError == False and modbusError != True and modbusErrorRate != None and modbusErrorRate > MODBUSWARNLEVEL and modbusErrorRate < 1:
+            logging.warning("[DeviceDcElwa] " + self.getidentifier() + " - Modbus error rate to hight " + str(modbusErrorRate) + ".")
+            modbusWarning = True
+        else:
+            modbusWarning = False
+
         value = ModbusRtuDevice.getdataset(self, "tempchip")
-        if value == 0 and modbusError == False:
+        if value == 0 and modbusError == False and registerError == False:
             logging.warning("[DeviceDcElwa] " + self.getidentifier() + " - No IR Connection to Device.")
             irError = True
             self.__irerror__ = True
@@ -265,12 +275,6 @@ class DeviceDcElwa(ModbusRtuDevice):
             irError = False
             self.__irerror__ = False
 
-        if self.__checkRegiterTimeStamp__() != True and modbusError == False:
-            logging.warning("[DeviceDcElwa] " + self.getidentifier() + " - Register values too old. Communication errors expected.")
-            registerError = True
-        else:
-            registerError = False
-
         healthState = 0
 
         #healthState warnings
